@@ -30,7 +30,7 @@ from .exceptions import (
     NoActiveContext,
     AmbiguousParseTree,
 )
-from .error_handling import ErrorHandler, error_handler, no_exit_handler
+from .error_handling import ErrorHandler, error_handler, no_exit_handler, extended_error_handler
 from .formatting.commands import get_formatter
 from .nargs import REMAINDER
 from .parameters import (
