@@ -89,7 +89,7 @@ class FixedFlag(Flag, metaclass=FixedFlagMeta):
                 member = cls._missing_str(value)
             except KeyError:
                 expected = ', '.join(cls._member_map_)
-                raise ValueError(f'Invalid {cls.__name__} value={value!r} - expected one of {expected}') from None
+                raise ValueError(f'Invalid {cls.__name__} {value=} - expected one of {expected}') from None
             else:
                 return ~member if invert else member  # pylint: disable=E1130
         elif not isinstance(value, int):
@@ -121,8 +121,7 @@ class FixedFlag(Flag, metaclass=FixedFlagMeta):
     def _decompose(self) -> List[FlagEnum]:
         if self._name_ is None or '|' in self._name_:  # | check is for 3.11 where pseudo-members are assigned names
             val = self._value_
-            members = ((mem, mem._value_) for mem in self.__class__)
-            return sorted(mem for mem, mem_val in members if mem_val & val == mem_val)  # noqa
+            return sorted(mem for mem in self.__class__ if (mem_val := mem._value_) & val == mem_val)  # noqa
         return [self]
 
     def __lt__(self, other: FlagEnum) -> bool:
@@ -160,4 +159,4 @@ def str_to_bool(value: str) -> bool:
         return True
     elif lower in {'f', 'false', 'n', 'no'}:
         return False
-    raise ValueError(f'Unable to parse boolean value from value={value!r}')
+    raise ValueError(f'Unable to parse boolean value from {value=}')
